pub struct BreakerConfig {
pub failure_threshold: u32,
pub open_cooldown: Duration,
pub half_open_max_probes: u32,
}Expand description
Circuit-breaker policy.
Fields
failure_threshold: u32Consecutive failures that trip the breaker from Closed to Open.
open_cooldown: DurationHow long the breaker stays Open before allowing a half-open probe.
half_open_max_probes: u32Concurrent probes permitted while HalfOpen.