pub struct ResilienceConfig {
pub request_timeout: Duration,
pub stream_idle_timeout: Duration,
pub retry: RetryConfig,
pub breaker: BreakerConfig,
pub bulkhead: BulkheadConfig,
}Expand description
The full resilience policy applied to one logical dependency.
Fields
request_timeout: DurationTimeout applied to each individual attempt of a non-streaming call.
stream_idle_timeout: DurationMaximum gap between two chunks of a streaming response before it is aborted.
retry: RetryConfigRetry policy.
breaker: BreakerConfigCircuit-breaker policy.
bulkhead: BulkheadConfigBulkhead policy.